import { FormControl } from '@mui/material';

import {
    StyledHelperText,
    StyledFormControlLabel,
    StyledRadio,
    StyledSpan,
    StyledRadioGroup,
} from './NsRadioGroup.styled';
import { NsLabel } from '../label';

import { NsRadioGroupProps } from './types';

const NsRadioGroup = (props: NsRadioGroupProps) => {
    const {
        items,
        helperText,
        label,
        onChange,
        color,
        disable,
        size,
        additionalProps,
        labelFontSize,
        darkModeEnabled = true,
        row,
    } = props;

    return (
        <>
            <FormControl data-testid={additionalProps?.testid}>
                <NsLabel size={labelFontSize}>{label}</NsLabel>
                <StyledRadioGroup
                    row={row}
                    aria-labelledby="radio-buttons-group-label"
                    defaultValue={items?.[0]?.value}
                    name="radio-buttons-group"
                    onChange={onChange}
                    color={color}
                    darkModeEnabled={darkModeEnabled}
                >
                    {items?.map((item, index) => (
                        <StyledFormControlLabel
                            id={`${index} `}
                            key={item?.id}
                            value={item?.value}
                            control={<StyledRadio className="custom-radio" />}
                            label={item?.label}
                            disabled={disable}
                            darkModeEnabled={darkModeEnabled}
                        />
                    ))}
                </StyledRadioGroup>
            </FormControl>
            {helperText ? (
                <StyledHelperText className={`ml-${size}`}>
                    <StyledSpan className="text-sm">{helperText}</StyledSpan>
                </StyledHelperText>
            ) : null}
        </>
    );
};

export default NsRadioGroup;
